@@ -8,7 +8,7 @@
    # echo output to screen
    cat("##\n## Markov Chain Monte Carlo Package (MCMCpack)\n")
    cat("## Copyright (C) 2003-", this.year,
-      " Andrew D. Martin and Kevin M. Quinn\n", sep="")
+      " Andrew D. Martin, Kevin M. Quinn, and Jong Hee Park\n", sep="")
    cat("##\n## Support provided by the U.S. National Science Foundation\n")
    cat("## (Grants SES-0350646 and SES-0350613)\n##\n")
    require(coda, quietly=TRUE)
